@@ -4,18 +4,19 @@
 #' Sets mode to \dQuote{local}, i.e., parallelization is turned
 #' off and all necessary stuff is cleaned up.
 #'
-#' For socket and mpi mode \code{\link[parallel]{stopCluster}} is called.
+#' For socket and mpi mode [parallel::stopCluster()] is called.
 #'
-#' For BatchJobs mode the subdirectory of the \code{storagedir}
+#' For BatchJobs mode the subdirectory of the `storagedir`
 #' containing the exported objects is removed.
 #'
-#' After a subsequent call of \code{\link{parallelStart}}, no exported objects
+#' After a subsequent call of [parallelStart()], no exported objects
 #' are present on the slaves and no libraries are loaded,
 #' i.e., you have clean R sessions on the slaves.
 #'
 #' @return Nothing.
 #' @export
 parallelStop = function() {
+
   # only do something if we are in "started" state
   if (isStatusStarted()) {
     if (isModeSocket() || isModeMPI()) {
@@ -27,16 +28,14 @@ parallelStop = function() {
       #    via S3 inheritance
       # b) stopCluster will also throw amn exception when none is registered. great, and apparently
       #    we have no way of asking whether one is alrealdy registered.
-      cl = get("default", envir=getFromNamespace(".reg", ns="parallel"))
+      cl = get("default", envir = getFromNamespace(".reg", ns = "parallel"))
       if (!is.null(cl)) {
-        stopCluster(cl=cl)
+        stopCluster(cl = cl)
         setDefaultCluster(NULL)
       }
     } else if (isModeBatchJobs()) {
-      # remove all exported libraries
-      options(parallelMap.bj.packages=NULL)
-      # remove exported objects
-      cleanUpBatchJobsExports()
+      # delete registry file dir
+      unlink(getBatchJobsRegFileDir(), recursive = TRUE)
     }
     if (!isModeLocal()) {
       showInfoMessage("Stopped parallelization. All cleaned up.")
@@ -49,5 +48,8 @@ parallelStop = function() {
   # in any case be in local / stopped mode now
   options(parallelMap.mode = MODE_LOCAL)
   options(parallelMap.status = STATUS_STOPPED)
+
+  # FIXME do we clean up log files?
+
   invisible(NULL)
 }
